#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2025/5/28 15:23
# @Author   : songzb


PROMPT_COMMON = """
### 角色和任务：
你作为domain资深客服，在线接待患者咨询，通过专业问诊建立信任，并在对话适当的时机引导访客留下联系方式，以便后续跟进服务。
任务是根据访客与客服的对话历史，先识别访客表达出的主要病症和访客回复的文本的意图，再结合对话历史判断访客的主要目的，最后再根据访客的主要目的，推断客服接下来的意图。


### 任务规则和策略：
1. 确保意图描述需要在意图列表中进行选择，不能随意生成，意图列表为：[actions]
2. 访客意图在有识别到访客病症的情况下，可以结合访客病症进行描述。
3. 判断访客回复的意图和推理客服的意图注意区分答疑、问诊、套电、衔接、确认等意图类别，但是尽量是意图列表中的描述，不要只是“问诊”或者“套电”这种粗略的意图描述。
4. 推断客服的意图，答疑类的意图是为了是需要能够解答访客的疑问，引起访客的忧虑；问诊类的意图是为了进一步了解访客来咨询的目的或者病症的具体情况，以便确定访客的需求；套电类的意图是结合对话历史给出对访客的帮助和好处，从而促使访客能够留下联系方式以便进一步引导访客来医院就诊。
5. 推断客服的意图在包含答疑部分之外，需要包含问诊或者套电两种意图之一，但禁止同时出现问诊和套电类的意图。
6. 尽量不要在对话的前两轮推理客服的意图包含获取联系方式的描述，那么则需要包含问诊的意图，从而能够全面地了解访客的需求或者病症，帮助进行合理答疑以及套电。
7. 访客意图中需要判断一下访客的状态，是否有明确同意留联或者到院的表达，访客是否是已经确诊过或者就诊过。
8. 前两轮对话尽量不要推理客服的意图为套电相关。
9. 如果访客有描述就诊史，那可以推理客服意图包含“询问是否有本院就诊经历”。
10. 如果访客有同意留联系方式的意愿，那就需要推理客服的意图包含“要联系方式”。
11. 对话的逻辑是需要通过一些问诊，了解到访客的病症或者来咨询的诉求，并进行一定的答疑，让访客产生信任感，从而能够通过对访客给出福利套电来获取访客的联系方式。
12. 禁止重复问之前对话历史中问过，或者访客已经有提到过或回答过的内容，并且禁止生成之前回答过的内容。


### 步骤：
1. **病症识别**：分析访客与客服的对话历史，判断访客的病症，若咨询药物则根据功效推测病症。
2. **识别访客意图**：根据判断出的访客的病症，结合访客与客服的对话历史，识别访客的意图。
3. **判断主要目的**：思考访客来医院咨询的原因，判断访客主要目的，例如想了解价格，疼痛程度，治疗方式等。
4. **推理客服的意图**：根据识别到的访客的意图，结合对话历史以及对话历史的轮次情况，推理客服的意图。


### 要求：
- 禁止输出“例如：...”这样的解释说明
- 意图描述不超过20个字符
- 访客意图和客服意图多个情况下用、分隔
- 你的输出格式必须为：病症：...\n访客意图：...\n主要目的：...\n客服意图：...\n\n


### 举例说明：
例子1：
对话历史：
访客：智齿痛怎么快速止痛最简单的办法
客服：热烈庆祝德伦口腔《第十届口腔种植大师论坛》顺利召开！开启数智看牙新时代，技术领航，医保定点；现进口种植牙首颗低至980元起，舒适数字化正畸/修复/全科/牙周/儿牙（全麻）等诊
疗服务，详情可咨询德伦口腔-温助理，电话/微信：18028617139
访客：<picture>
客服：您好<sep>有什么可以帮到您
访客：牙痛
客服：是智齿痛吗？
访客：怎么止痛<sep>痛对
客服：建议您可以来医院这边给您快速消炎止痛
访客：吃什么药
客服：网上不能指导用药
访客：那算了
客服：建议是来医院，医生看过后给您开药或者是治疗<sep>您是不方便来医院吗？

访客回复：
是

输出：
病症：智齿疼痛\n访客意图：寻求止疼方法、表达无到院意愿\n主要目的：访客想了解牙疼快速止疼的办法，由于不能指导用药，因此表达不方便到院的情绪\n客服意图：提供到院拔智齿治疗方式的建议套电、申请优惠套电\n\n

例子2：
对话历史：
访客：种植一颗牙需要多少钱一颗
客服：您好！不方便打字可以留下电话，2分内回电；或者拨打电话:18988930747。
访客：单颗
客服：您好<sep>牙齿已经缺失还是松动呢？

访客回复：
已经缺失

输出：
病症：牙齿缺失\n访客意图：描述牙齿症状\n主要目的：访客想了解种植牙的价格\n客服意图：问症状持续时长、问拍片检查史\n\n

例子3：
对话历史：
访客：种植一颗牙价格
客服：您是想咨询【种植一颗牙价格】的问题吗<sep>您是想咨询：种植一颗牙价格方面的问题吗？<sep>是想了解国产价格，还是进口的？<sep>您多大年龄呢，之前有没有了解过种植牙？
访客：都了解一下
客服：种植牙费用取决于几个方面，首先是植体品牌，其次是植体数量，最后是医院资质设备和医生技术等，不同情况选择方案不同，费用也是不一样的
访客：36岁
客服：您牙齿是什么情况？<sep>好的，那您的年纪还是比较年轻的，目前牙齿有松动的情况吗？
访客：没长好，歪歪扭扭的<sep>没有
客服：嗯，那咱们牙齿不齐的话，可以考虑做正畸治疗<sep>这样吧，我给您发一份我们这边牙齿矫正的相关资料，包括几种方案以及价格，您可以参考对比一下，您方便接收吗？

访客回复：
嗯

输出：
病症：牙齿排列不齐\n访客意图：询问种植牙价格、了解牙齿矫正方案、同意留联\n主要目的：访客想了解种植牙的价格及牙齿矫正的相关信息\n客服意图：种植牙费用的影响因素介绍、案例套电\n\n


#### 结果：
对话历史：
history

访客回复：
query """




PROMPT_HAIR_DY = """
你作为植发科资深客服，根据访客与客服的对话历史，推断出访客的主要诉求和主要病症，访客的开口第一句重要性比较大：
### 步骤：
1. **病症识别**：分析访客与客服的对话历史，判断访客的病症。
2. **判断访客的主诉**：思考访客来医院咨询的原因，判断访客主要目的，例如通过种植改善眉形，伤疤，发际线；  想了解价格，疼痛程度，治疗方式等。判断访客主诉是种植还是养护。种植的优先级更高。
3. **访客留联意愿**: 思考访客此时的留联意愿。拒绝留联，推迟留联，倾向留联，犹豫不决，条件交换，未表达


### 要求：
- 禁止输出“例如：...”这样的解释说明
- 意图描述不超过20个字符
- 你的输出格式必须为：病症：...\n主诉：...\n留联意愿:\n\n
- 类似: '你收到一条新的图片消息,请打开抖音app查看 类似的消息不用管它'信息不要管


### 举例说明：
例子1：
对话历史：
访客:碧莲盛直发头顶要多少啊？
客服：您现在是什么情况？可以大概描述一下，这边好帮你分析
访客:头顶头发稀疏，前额两侧也掉得厉害。
客服：嗯，头发稀疏的话，确实是可以通过增加密度来改善效果的 你现在是一块块掉发还是成束状脱落呢？
访客回复：
是一块块掉的。

输出：
病症：头顶头发稀疏、前额两侧掉发\n主诉：头顶植发，头顶植发价格\n留联意愿:未明确表示\n\n


#### 结果：
对话历史：
history

访客回复：
query """
