#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2025/5/29 22:57
# @Author   : songzb


# 识别多轮访客意图
PROMPT_intent = """
作为domain资深客服，你需要根据访客与客服的对话历史，先判断访客的主要目的，再识别访客回复的文本的意图，意图描述需要满足以下规则：
1. 确保意图描述需要在意图列表中进行选择，不能随意生成，意图列表为：[intents]
2. 根据访客与客服的对话历史，来判断访客就真的主要目的，也就是心理原因，从而可以结合访客的心理原因进行意图类别的识别
3. 意图识别更多的依赖于对于当前访客回复文本的理解，不能完全来源于对话历史


### 步骤：
1. **判断访客心理原因**：分析访客与客服的对话历史，判断访客来咨询的心理原因，例如想了解价格，疼痛程度，治疗方式等
2. **识别访客意图**：根据判断出的访客的心理原因，结合访客与客服的对话历史，从意图列表中给选择一个最适合的作为访客意图


### 要求：
- 输出的访客意图必须属于意图列表
- 你输出的意图数量为1-2个，不能超过2个，并且2个的情况下用、分隔，输出的意图描述不超过16个字符
- 你的输出格式必须为：心理原因：...\n访客意图：...\n
- 禁止输出解释说明


#### 结果：
对话历史：
history

访客回复：
query
"""

PROMPT_action_without_template = """
作为domain资深医生，你需要根据访客与客服的对话历史，先判断访客的主要目的，再识别客服回复的文本的意图，意图描述需要满足以下规则：
1. 确保意图描述需要在意图列表中进行选择，不能随意生成，意图列表为：[actions]
2. 根据访客与客服的对话历史，来判断访客就真的主要目的，也就是心理原因，从而可以结合访客的心理原因进行客服意图类别的识别
3. 意图识别更多的依赖于对于当前客服回复文本的理解，不能完全来源于对话历史


### 步骤：
1. **判断访客心理原因**：分析访客与客服的对话历史，思考访客来医院咨询的原因，例如想了解价格，疼痛程度，治疗方式等
2. **识别客服意图**：根据判断出的访客的心理原因，结合访客与客服的对话历史，理解客服回复的文本，从意图列表中给选择一个最适合的作为客服意图


### 要求：
- 输出的客服意图必须属于意图列表
- 你输出的意图数量为1-8个，不能超过8个，并且多个的情况下用、分隔，输出的意图描述不超过36个字符
- 意图描述尽量一个句子至少一个
- 你的输出格式必须为：心理原因：...\n客服意图：...\n
- 禁止输出解释说明


#### 结果：
对话历史：
history

客服回复：
query
"""

PROMPT_action_with_template = """
作为domain资深医生，你需要根据访客与客服的对话历史，先判断访客的主要目的，再识别客服回复的文本的意图，意图描述需要满足以下规则：
1. 确保意图描述需要在意图列表中进行选择，不能随意生成，意图列表为：[actions]
2. 根据访客与客服的对话历史，来判断访客就真的主要目的，也就是心理原因，从而可以结合访客的心理原因进行客服意图类别的识别
3. 意图识别更多的依赖于对于当前客服回复文本的理解，不能完全来源于对话历史


### 步骤：
1. **判断访客心理原因**：分析访客与客服的对话历史，思考访客来医院咨询的原因，例如想了解价格，疼痛程度，治疗方式等
2. **识别客服意图**：根据判断出的访客的心理原因，结合访客与客服的对话历史，理解客服回复的文本，从意图列表中给选择一个最适合的作为客服意图


### 要求：
- 输出的客服意图必须属于意图列表
- 你输出的意图数量为1-8个，不能超过8个，并且多个的情况下用、分隔，输出的意图描述不超过36个字符
- 意图描述尽量一个句子至少一个
- 你的输出格式必须为：心理原因：...\n客服意图：...\n
- 禁止输出解释说明


### 举例说明：
例子1：
对话历史：
访客：智齿痛怎么快速止痛最简单的办法                                                                                                                                         
客服：热烈庆祝德伦口腔《第十届口腔种植大师论坛》顺利召开！开启数智看牙新时代，技术领航，医保定点；现进口种植牙首颗低至980元起，舒适数字化正畸/修复/全科/牙周/儿牙（全麻）等诊
疗服务，详情可咨询德伦口腔-温助理，电话/微信：18028617139
访客：<picture>
客服：您好<sep>有什么可以帮到您
访客：牙痛
客服：是智齿痛吗？
访客：怎么止痛<sep>痛对
客服：建议您可以来医院这边给您快速消炎止痛
访客：吃什么药
客服：网上不能指导用药
访客：那算了
客服：建议是来医院，医生看过后给您开药或者是治疗<sep>您是不方便来医院吗？
访客：是

客服回复：
客服：我的微信号码：18028617139，您可以添加我<sep>您如果打算到医院系统治疗，以及拔智齿，您可以随时微信联系我<sep>我可以帮您申请免费拍片，以及尽量申请优惠

输出：
心理原因：访客想了解牙疼快速止疼的办法，由于不能指导用药，因此表达不方便到院的情绪\n客服意图：报联话术、治疗方式介绍、优惠套电话术\n\n

例子2：
对话历史：
访客：种植一颗牙需要多少钱一颗
客服：您好！不方便打字可以留下电话，2分内回电；或者拨打电话:18988930747。
访客：单颗
客服：您好<sep>牙齿已经缺失还是松动呢？
访客：已经缺失

客服回复：
客服：缺失多久了呢？<sep>有没拍片看过牙槽骨的情况呢？

输出：
心理原因：访客想了解种植牙的价格\n客服意图：问持续时长、问检查史\n\n


#### 结果：
对话历史：
history

客服回复：
query
"""

# 12. 结合对话中访客提到的病症，并且针对对话历史中访客来咨询的主要目的，进行引导回复，下面给一些不同场景下的较好的客服回复的逻辑：
#     1).访客主要表达“怕疼”，可以去介绍疼痛程度的感受情况，以及专家技术介绍，加强患者信心；
#     2).访客表达咨询价格，可以简单介绍访客咨询的内容，介绍机构正规性，不会有隐形消费，最后给出近期价格优惠活动，消除访客担忧；
#     3).访客表达“明天可以吗”或者肯定回答客服邀约的话术，这类有意向来院的情况，优先回答给访客预约来院的方式和便捷性，并且询问访客联系方式；
#     4).访客在客户套电之后，表达“考虑中”的意思，则可以加强引导以及对项目的介绍，给予访客信息；
#     5).访客表达“没有去医院”的意思，则可以通过下危害来引导访客，并视情况给予访客治疗的信心再询问访客联系方式；
PROMPT_clue_client = """
你作为domain资深客服，根据访客与客服的对话历史，先识别访客表达出的主要病症和访客回复的文本的意图，再结合对话历史判断访客的主要目的，最后再根据访客的主要目的，推断客服接下来的意图，意图描述需要满足以下规则：
1. 确保意图描述需要在意图列表中进行选择，不能随意生成，意图列表为：[actions]
2. 访客意图在有识别到访客病症的情况下，可以结合访客病症进行描述。
3. 判断访客回复的意图和推理客服的意图注意区分答疑、问诊、套电、衔接、确认等意图类别，但是尽量是意图列表中的描述，不要只是“问诊”或者“套电”这种粗略的意图描述。
4. 推断客服的意图，答疑类的意图是为了是需要能够解答访客的疑问，引起访客的忧虑；问诊类的意图是为了进一步了解访客来咨询的目的或者病症的具体情况，以便确定访客的需求；套电类的意图是结合对话历史给出对访客的帮助和好处，从而促使访客能够留下联系方式以便进一步引导访客来医院就诊。
5. 推断客服的意图在包含答疑部分之外，需要包含问诊或者套电两种意图之一，但禁止同时出现问诊和套电类的意图。
6. 尽量不要在对话的前两轮推理客服的意图包含获取联系方式的描述，那么则需要包含问诊的意图，从而能够全面地了解访客的需求或者病症，帮助进行合理答疑以及套电。
7. 访客意图中需要判断一下访客的状态，是否有明确同意留联或者到院的表达，访客是否是已经确诊过或者就诊过。
8. 前两轮对话尽量不要推理客服的意图为套电相关。
9. 如果访客有描述就诊史，那可以推理客服意图包含“询问是否有本院就诊经历”。
10. 如果访客有同意留联系方式的意愿，那就需要推理客服的意图包含“要联系方式”。
11. 对话的逻辑是需要通过一些问诊，了解到访客的病症或者来咨询的诉求，并进行一定的答疑，让访客产生信任感，从而能够通过对访客给出福利套电来获取访客的联系方式。
12. 禁止重复问之前对话历史中问过，或者访客已经有提到过或回答过的内容，并且禁止生成之前回答过的内容。


### 步骤：
1. **病症识别**：分析访客与客服的对话历史，判断访客的病症，若咨询药物则根据功效推测病症。
2. **识别访客意图**：根据判断出的访客的病症，结合访客与客服的对话历史，识别访客的意图。
3. **判断主要目的**：思考访客来医院咨询的原因，判断访客主要目的，例如想了解价格，疼痛程度，治疗方式等。
4. **推理客服的意图**：根据识别到的访客的意图，结合对话历史以及对话历史的轮次情况，推理客服的意图。


### 要求：
- 禁止输出“例如：...”这样的解释说明
- 意图描述不超过20个字符
- 访客意图和客服意图多个情况下用、分隔
- 你的输出格式必须为：病症：...\n访客意图：...\n主要目的：...\n客服意图：...\n\n


### 举例说明：
例子1：
对话历史：
访客：智齿痛怎么快速止痛最简单的办法
客服：热烈庆祝德伦口腔《第十届口腔种植大师论坛》顺利召开！开启数智看牙新时代，技术领航，医保定点；现进口种植牙首颗低至980元起，舒适数字化正畸/修复/全科/牙周/儿牙（全麻）等诊
疗服务，详情可咨询德伦口腔-温助理，电话/微信：18028617139
访客：<picture>
客服：您好<sep>有什么可以帮到您
访客：牙痛
客服：是智齿痛吗？
访客：怎么止痛<sep>痛对
客服：建议您可以来医院这边给您快速消炎止痛
访客：吃什么药
客服：网上不能指导用药
访客：那算了
客服：建议是来医院，医生看过后给您开药或者是治疗<sep>您是不方便来医院吗？

访客回复：
是

输出：
病症：智齿疼痛\n访客意图：寻求止疼方法、表达无到院意愿\n主要目的：访客想了解牙疼快速止疼的办法，由于不能指导用药，因此表达不方便到院的情绪\n客服意图：提供到院拔智齿治疗方式的建议套电、申请优惠套电\n\n

例子2：
对话历史：
访客：种植一颗牙需要多少钱一颗
客服：您好！不方便打字可以留下电话，2分内回电；或者拨打电话:18988930747。
访客：单颗
客服：您好<sep>牙齿已经缺失还是松动呢？

访客回复：
已经缺失

输出：
病症：牙齿缺失\n访客意图：描述牙齿症状\n主要目的：访客想了解种植牙的价格\n客服意图：问症状持续时长、问拍片检查史\n\n

例子3：
对话历史：
访客：种植一颗牙价格
客服：您是想咨询【种植一颗牙价格】的问题吗<sep>您是想咨询：种植一颗牙价格方面的问题吗？<sep>是想了解国产价格，还是进口的？<sep>您多大年龄呢，之前有没有了解过种植牙？
访客：都了解一下
客服：种植牙费用取决于几个方面，首先是植体品牌，其次是植体数量，最后是医院资质设备和医生技术等，不同情况选择方案不同，费用也是不一样的
访客：36岁
客服：您牙齿是什么情况？<sep>好的，那您的年纪还是比较年轻的，目前牙齿有松动的情况吗？
访客：没长好，歪歪扭扭的<sep>没有
客服：嗯，那咱们牙齿不齐的话，可以考虑做正畸治疗<sep>这样吧，我给您发一份我们这边牙齿矫正的相关资料，包括几种方案以及价格，您可以参考对比一下，您方便接收吗？

访客回复：
嗯

输出：
病症：牙齿排列不齐\n访客意图：询问种植牙价格、了解牙齿矫正方案、同意留联\n主要目的：访客想了解种植牙的价格及牙齿矫正的相关信息\n客服意图：种植牙费用的影响因素介绍、案例套电\n\n


#### 结果：
对话历史：
history

访客回复：
query
"""

# 1.确保意图描述需要在意图列表中进行选择，不能随意生成，意图列表为：[actions]，其中不同类别意图的介绍如下：
# PROMPT_clue_server = """
# 你作为domain资深客服，结合访客与客服的对话历史，识别客服回复的文本的意图，意图描述需要满足以下规则：
# 1.意图描述需要参考意图列表，描述相对详细一些，意图列表为：[actions]，其中不同类别意图的介绍如下：
#     1）答疑类的意图是为了是需要能够解答访客的疑问，引起访客对病症的关心或者忧虑。
#     2）问诊类的意图是为了进一步了解访客来咨询的目的或者病症的具体情况，以便确定访客的需求。
#     3）套电类的意图是结合对话历史给出对访客的帮助和好处，从而促使访客能够留下联系方式以便进一步引导访客来医院就诊。
#     4）确认类的意图是代表客服通过确认性的询问，确定某些信息，有助于对话的进行。
#     5）衔接类的意图是一些比较通用的衔接的话语。
# 2.需要从意图列表中的选择合适的标签进行描述，禁止只是“问诊”、“套电”、”答疑“或者”套电话术“这种粗略的意图描述。
# 3.客服意图的描述只能依赖于对当前客服回复文本的理解，禁止来源于对话历史。
# 4.客服意图描述可以结合对话历史中访客表达的主要病症。
# 5.需要理解客服回复表达了多少个独立的意思，对应给出合适的意图描述。
#
#
# ### 步骤：
# 1. **理解对话历史**：分析访客与客服的对话历史，理解访客想了解信息和客服回复的文本表达的意思。
# 2. **识别客服意图**：结合访客与客服的对话历史以及对话轮次情况，识别当前客服的回复文本的意图，从意图列表中给选择最适合的作为客服意图。
#
#
# ### 要求：
# - 禁止输出“例如：...”这样的解释说明
# - 意图描述不超过20个字符
# - 意图多个的情况下用、分隔。
# - 你的输出格式必须为：客服意图：...
#
#
# ### 举例说明：
# 例子1：
# 对话历史：
# 访客：何首乌的功效与作用<sep>掉发
# 客服：您是男士还是女士，今年多大了呢？
# 访客：男孩十九
# 客服：您掉发多长时间了呢？
# 访客：几个月
# 客服：您头发容易出油吗？
# 访客：嗯
# 客服：现在是感觉整体发量有减少了吗
# 访客：有
#
# 客服回复：
# 嗯，了解了<sep>您这个是皮下的毛囊处于不健康的状态了，毛囊吸收不到充足的营养，才会这样的<sep>目前您有改善防护的措施吗？
#
# 输出：
# 客服意图：毛囊病因症状介绍、询问采取的治疗方式
#
#
# #### 结果：
# 对话历史：
# history
#
# 客服回复：
# query
# """

PROMPT_clue_server = """
你作为domain资深客服，判断客服回复的文本的意图，意图描述需要满足以下规则：
1.意图描述需要参考意图列表，描述相对详细一些，意图列表为：[actions]，其中不同类别意图的介绍如下：
    1）答疑类的意图是为了是需要能够解答访客的疑问，引起访客对病症的关心或者忧虑。
    2）问诊类的意图是为了进一步了解访客来咨询的目的或者病症的具体情况，以便确定访客的需求。
    3）套电类的意图是结合对话历史给出对访客的帮助和好处，从而促使访客能够留下联系方式以便进一步引导访客来医院就诊。
    4）确认类的意图是代表客服通过确认性的询问，确定某些信息，有助于对话的进行。
    5）衔接类的意图是一些比较通用的衔接的话语。
2.需要从意图列表中的选择合适的标签进行描述，禁止只是“问诊”、“套电”、”答疑“或者”套电话术“这种粗略的意图描述。
3.需要理解客服回复表达了多少个独立的意思，对应给出合适的意图描述。


### 步骤：
1. **理解对话历史**：分析并理解客服回复的文本表达的意思。
2. **识别客服意图**：识别当前客服的回复文本的意图，从意图列表中给选择最适合的作为客服意图。


### 要求：
- 禁止输出“例如：...”这样的解释说明
- 意图描述不超过20个字符
- 意图多个的情况下用、分隔。
- 你的输出格式必须为：客服意图：...


### 举例说明：
例子1：
客服回复：
嗯，了解了<sep>您这个是皮下的毛囊处于不健康的状态了，毛囊吸收不到充足的营养，才会这样的<sep>目前您有改善防护的措施吗？

输出：
客服意图：毛囊病因症状介绍、询问采取的治疗方式


#### 结果：
客服回复：
query

输出：
"""
