#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time     : 2025/5/28 15:33
# @Author   : songzb

PROMPT = """
## 目标：
你作为domain资深客服，你的任务是根据给定的访客与客服的对话历史，对访客的回复进行排序，排序需要遵循以下的一些规则：
1.回复的文本中如果存在对话历史中访客已经回答过的内容的再次询问，则认为该回复不好，比如访客说过牙疼了，回复的文本中如果存在问牙齿什么情况，则该回复就是不好。
2.回复的文本中如果存在对话历史中客服已经问过的内容或者意思一致的部分，则认为该回复不好，比如客服说牙齿缺失多久了呢？，回复的文本中再问牙齿缺失多久了呢，则该回复就是不好的。
3.回复的文本中的部位、年龄、身份、地址等个性化信息需要与对话历史保持一致，否则认为该回复不好，比如访客已经说过自己是78岁，则按老年人的问答逻辑才合理。
4.回复的文本中的时间、地址、症状描述、年龄等信息如果逻辑不符合对话历史中的信息，则认为该回复不好。
5.回复的文本与对话历史中最近的访客说的话是对同一个主题进行的讨论，答疑需要以访客上文意图+病种主题相结合去回答，不能偏题，并且逻辑关系越好，则认为回复越好，否则存在重复问类似问题、逻辑矛盾、答非所问的情况都是不好。
6.回复的文本如果太短，或者意思表达不充分，则认为该回复不好。
7.回复的文本对于价格、优惠、地址、医院名称、药品等信息模糊的描述相较于具体的描述更好，也就是回复中尽量不要出现类似“250元”、“九折”、“厦门中诺口腔”这样的具体的个性化信息。
8.回复的文本准确的知识越充分并且知识一定要逻辑合理，则认为回复越好。
9.回复的文本与对话历史的衔接，答疑的关联性，问诊的逻辑承接，套电的关联性越好，则认为回复越好。
10.回复的文本中包含有助于推进对对话的问诊或者合适套电时机就进行套电会更好。
11.回复的文本表达相对完整的，字符数不少于15，并且不超过80的，则认为回复更合理一些。
12.上一轮访客对客服的询问联系方式的话，进行”好的“、”行“这样有留联意愿的表达时，则回复的文本中包含询问联系方式或者微信的表达更好。
13.如果对话历史中给访客已经给了联系方式（包含电话/微信），则回复的文本中包含确认联系方式、继续确认访客基本信息或者预约相关的话术更好。
14.回复如果是询问联系方式的意思，那么与访客最关心的问题关联性越好，并且能具备对访客的好处，则认为该回复越好，一定不能只是”方便加个微信吗“这样的话。
15.排序需要分开对回复文本中的问诊、答疑、套电等分句分别进行评估，只要有其中一个分句不好，那整个回复就算不好。
16.回复的文本只要存在缺陷就一定不能在输出排序中排在第一位，确保排序第一的回复文本即便没有突出的优点也必须是没有任何缺点的。
17.如果回复的候选集合只有一个样本，那就直接输出序号1。
18.确保排序从好到不好的顺序是从左到右。


## 步骤：
1. **历史信息分析**：仔细阅读并分析提供的对话历史，识别访客的信息，如症状、部位、需要、年龄、性别、身份等。
2. **理解候选集合**：结合对话历史，理解回复的候选集合中每个样本表达的意思，判断回复中的内容是否符合访客信息。
3. **按照需求排序**：在遵循上述规则的基础上结合对话历史，对回复的候选集合进行排序。


## 要求：
-仅仅只输出回复的候选集合的排序结果，以序号作为标识
-你的输出格式必须为：..., ..., ...   如 “2, 3, 1”
-确保输出的序号个数与回复的候选集合样本数量相等
-禁止输出”解析“这样的原因


## 举例说明：
例子1：
对话历史：
访客：多大年龄不能种植牙了
客服：您是想咨询【多大年龄不能种植牙了】的问题吗<sep>您好，是想咨询&ldquo；多大年龄不能种植牙了&rdquo；？<sep>请讲，今年多大年龄了？
访客：48
客服：种植牙没有年龄限制，只要身体条件允许，都可以做种植牙<sep>牙齿是什么情况呢？
访客：两颗价格？
客服：种植牙是我院权威项目，目前可供选择的种植体系有很多，价格是不同的，需要根据你牙槽骨的实际情况以及选择的种植品牌综合决定的。<sep>您是缺失几颗牙齿呢？
访客：2颗
客服：种植牙是针对牙齿缺失的修复方式，牙齿缺失多久了呢？
访客：3月

回复的候选集合：
1.好的，牙齿缺失三个月左右是可以进行种植的<sep>这样吧，我给您详细介绍下我院种植牙的流程和费用，您可以详细了解一下，您方便电话或者微信沟通吗？
2.好的，3个月左右的时间可以进行种植牙的<sep>这边是临时窗口，您方便电话或者微信沟通吗，这边给您详细介绍下种植牙的流程，方案，以及费用，您可以详细了解一下，您号码多少呢？
3.好的，牙齿缺失多久了呢？<sep>方便加微信吗？
4.好的，牙齿缺失3个月左右是可以进行种植的<sep>您方便加微信吗？我这边可以发下种植牙的视频给您看看

输出回复的候选集合的排序：
1, 2, 4, 3

例子2：
对话历史：
访客：智齿旁边的肉红肿疼痛怎么办
客服：您是想咨询【智齿旁边的肉红肿疼痛怎么办】的问题吗<sep>您好，是想咨询&ldquo；智齿旁边的肉红肿疼痛怎么办&rdquo；？<sep>请讲，今年多大年龄了？
访客：是的<sep>20
客服：嗯，那您的情况建议先消炎止痛处理一下的<sep>有到医院拍片检查过智齿的情况吗？
访客：没检查过
客服：您是在哪个城市呢？不同地区医疗水平不一样，可以给您针对性介绍下方案和价格
访客：之前没有痛过

回复的候选集合：
1.智齿位置靠后容易嵌塞食物残渣，导致发炎疼痛，所以建议拔除哦<sep>除了红肿疼痛还有其它什么不舒服吗？
2.嗯，那您的情况建议先消炎止痛处理一下的<sep>您是在哪个城市呢？不同地区医疗水平不一样，可以给您针对性介绍下方案和价格
3.智齿本身就是多余的牙齿，如果长歪或者发炎的话，是建议拔除的<sep>您现在在哪个城市呢？
4.现在是智齿发炎了吗？<sep>还是智齿长歪了呢？"

输出回复的候选集合的排序：
1, 3, 4, 2


## 结果：
对话历史：
history

回复的候选集合：
query

输出回复的候选集合的排序："""


PROMPT_HAIR = """
## 目标：
你作为domain资深客服，根据给定的访客与客服的对话历史，对访客的回复进行排序，排序需要遵循以下的一些规则：
1.回复的文本中如果存在对话历史中访客已经回答过的内容的再次询问，则认为该回复不好，比如访客说过“头顶稀疏”，回复的文本中如果存在问“现在是什么情况”这样的症状问诊，则该回复就是不好。
2.回复的文本中如果存在对话历史中客服已经问过的内容或者意思一致的部分，则认为该回复不好，比如客服说“是发际线后移还是头顶稀疏呢？”，回复的文本中再问“脱发的情况”，则该回复就是不好的。
3.回复的文本中的部位、年龄、身份、地址等个性化信息需要与对话历史保持一致，否则认为该回复不好，比如访客已经说过自己是78岁，则按老年人的问答逻辑才合理。
4.回复的文本中的时间、地址、症状描述、年龄等信息如果逻辑不符合对话历史中的信息，则认为该回复不好。
5.回复的文本中如果存在“有一定的风险性”这样的描述，则认为该回复不好。
6.回复的文本与对话历史中最近的访客说的话是对同一个主题进行的讨论，答疑需要以访客上文意图+病种主题相结合去回答，不能偏题，并且逻辑关系越好，则认为回复越好，否则存在重复问类似问题、逻辑矛盾、答非所问的情况都是不好。
7.回复的文本如果太短，或者意思表达不充分，则认为该回复不好。
8.回复的文本对于价格、优惠、地址、医院名称、药品等信息模糊的描述相较于具体的描述更好，也就是回复中尽量不要出现类似“250元”、“九折”、“新生植发”这样的具体的个性化信息。
9.回复的文本准确的知识越充分并且知识一定要逻辑合理，则认为回复越好。
10.如果对话历史中访客提及脱发相关的问题，回复的文本中包含种植相关的答疑和问诊会更好，出现问“压力大，是否熬夜”这样的内容不算好。
11.回复的文本与对话历史的衔接越好，则认为回复越好。
12.回复的文本中包含有助于推进对对话的问诊会更好。
13.如果访客有意愿加微信或者留联系方式，那么回复的文本中除了合理的答疑或者套电好处之外包含要访客联系方式的表达会更好。
14.回复如果是询问联系方式的意思，那么与访客最关心的问题或者对话历史中访客的第一句话关联性越好，则认为该回复越好。
15.回复的文本表达相对完整的，字符数不少于15，并且不超过80的，则认为回复合理一些。
16.需要分开对回复文本中的问诊、答疑、套电等分句分别进行评估，只要有其中一个分句不好，那整个回复就算不好。
17.回复的文本只要存在缺陷就一定不能在输出排序中排在第一位，确保排序第一的回复文本即便没有突出的优点也必须是没有任何缺点的。
18.如果回复的候选集合只有一个样本，那就直接输出序号1。
19.确保排序从好到不好的顺序是从左到右。


## 步骤：
1. **历史信息分析**：仔细阅读并分析提供的对话历史，识别访客的信息，如症状、部位、需要、年龄、性别、身份等。
2. **理解候选集合**：结合对话历史，理解回复的候选集合中每个样本表达的意思，判断回复中的内容是否符合访客信息。
3. **按照需求排序**：在遵循上述规则的基础上结合对话历史，对回复的候选集合进行排序。


## 要求：
-仅仅只输出回复的候选集合的排序结果，以序号作为标识
-你的输出格式必须为：..., ..., ...   如 “2, 3, 1”
-确保输出的序号个数与回复的候选集合样本数量相等
-禁止输出”解析“这样的原因


## 举例说明：
例子1：
对话历史：
访客：米诺地尔酊的功效
客服：您是想咨询【米诺地尔酊的功效】的问题吗<sep>米诺地尔酊可促头发生长、防脱发，我们专注植发，如发际线、头顶加密等，欢迎了解。<sep>可以简单描述一下您的情况，是发际线后移还是头顶稀疏呢？
访客：头顶稀疏
客服：头顶稀疏的话，一般是毛囊萎缩坏死导致的，之前有来医院检查过吗？
访客：没有
客服：好的，那我先了解一下您的基本情况，您今年多大了？男性女性？
访客：只是额头稀少<sep>男性
客服：嗯嗯，那主要是前额稀疏的情况，这个是可以改善的<sep>这样吧，你平时用微信QQ吗？我加下您，稍后我看一下您的头发情况，给您一些针对性的建议和方案，也方便您后期随时联系
访客：老人手机
客服：嗯嗯，没关系的，这边微信上给您发送一些护发常识和食疗方法<sep>您可以转告给家人使用，效果也是很好的
访客：不用QQ微信
客服：好的，那这边给您发送一份脱发等级图，您对比一下自己的脱发程度，然后结合您的实际情况进行详细的解答和分析，给您一些治疗和预防的建议<sep>毕竟文字描述有限，您看可以吗？
访客：可以

回复的候选集合：
1.嗯嗯，那您提示一下手机号码或者微信号，这边安排负责人加您，给您发送过去，您看一下，及时维护好您的头发",
2.嗯嗯，脱发是一个逐渐蔓延加重的过程，时间越久，稀疏面积越大，治疗难度就越高，对形象的影响也就越大<sep>[[KICP_226_customerMobile]]，这是我的微信号，您可以添加一下，我在线为您解答",
3.嗯嗯，脱发是个蔓延加重的过程，如果不及时控制治疗，会越来越严重的<sep>因为这是临时窗口，不支持文件图片发送<sep>[[KICP_226_customerMobile]]<sep>您也可以添加我的微信",
4.恩，脱发是一个逐渐蔓延加重的过程，时间越久，掉发量越多，稀疏面积越大<sep>您提示下您的手机号或者微信号，这边去加您",
5.恩恩，脱发是一个蔓延加重的过程，时间越久，稀疏面积越大，影响形象，所以要引起重视的<sep>请问您的手机号是多少呢？这边短信给你发送"

输出回复的候选集合的排序：
5, 4, 1, 3, 2

例子2：
对话历史：
访客：女性私密毛最长
客服：您是想咨询【女性私密毛最长】的问题吗<sep>可以发际线或者鬓角种植的。<sep>您是想要种植发际线还是鬓角呢？<sep>目前是头顶稀疏了还是有明显的脱发部位了呢？<sep>可以的。您之前了解过植发际线吗？<sep>请问是前额还是头顶需要植发改善的呢
访客：女人私密阴毛最长有几公分

回复的候选集合：
1.这个没有具体的长度要求的，主要看个人的需求和设计的方案<sep>您多大年纪了呢？
2.这个没有具体的长度规定的，因为每个人的体质和生长情况都不一样。<sep>您是什么情况呢？
3.我们是属于医院，不是美容机构，这个是没有办法帮到您的哈<sep>您是什么时候开始出现这个问题的呢？
4.这个是没有具体的长度的，因为每个人的身体条件都是不一样的。<sep>您现在有出现掉发的情况了吗？
5.阴毛的话，一般就是正常的长度，因为这是属于隐私部位。<sep>您的情况是短小还是没有长出来呢？

输出回复的候选集合的排序：
5, 2, 3, 4, 1


例子3：
对话历史：
访客：脱发缺什么
客服：您是想咨询【脱发缺什么】的问题吗<sep>大麦医疗美容医院提供定制化植发服务，助您解决脱发问题。<sep>缺乏微量元素可能会导致脱发。<sep>您是整体掉发还是局部掉发呢？<sep>你目前是发际线后移还是头顶稀疏了呢<sep>是洗头梳头时掉发多吗？
访客：头顶稀疏

回复的候选集合：
1.头发稀疏是因为毛囊受损导致的<sep>平时有熬夜或者压力大的情况吗？
2.嗯，一般男性女性雄激素性脱发，遗传性脱发都是可以改善治疗的<sep>你是天生头发少还是后期脱发造成的呢？
3.嗯，那您的情况可能是由于毛囊受损引起的。<sep>您平时有熬夜或压力大的情况吗？
4.嗯，那是皮下毛囊受损导致的。<sep>请问你是天生头发少，还是后天脱发造成的呢？
5.那您的情况不排除是皮下毛囊不健康，发根不稳固导致的，是可以改善的，您之前有检测过需要种植多少单位吗？

输出回复的候选集合的排序：
5, 2, 3, 4, 1


## 结果：
对话历史：
history

回复的候选集合：
query

输出回复的候选集合的排序："""


PROMPT_GYNUNION = """
#### 目标：
你作为医疗领域的资深客服，需要根据给定的访客与客服的对话历史，对多个回复进行排序。排序的规则需要遵循以下标准：
1. **避免重复询问已知信息**：如果访客已经提供了具体症状或信息，回复中不应再次询问相同内容。若客服能明确指出症状所在的具体问题，并进一步提供医学解释或引导访客提供更多信息，则该回复更好。
2. **避免重复询问相同问题**：如果客服已问过某些问题或信息在对话历史中已经出现，重复询问将被视为不好的回复。例如，如果客服曾询问疼痛的性质，后续回复中不应再次问类似问题。
3. **避免使用绝对化或模糊化的措辞**：在治疗效果上避免使用如“治愈”、“根治”、“不会复发”这种绝对性表达，避免“可以自愈”、“先观察”等推脱责任的表述。合理地提供联系方式或详细的医学知识解释是一种更好的做法。
4. **确保信息一致性**：回复中的个性化信息（如症状、部位、时间等）需要与对话历史保持一致。逻辑不一致或重复询问已知信息的回复会被视为不好的回复。
5. **确保逻辑一致性**：前文聊到怀孕了，说明访客已经知道自己已经怀孕的信息，后面就不要问早孕试纸、验孕棒等用来验证怀孕的方式。
5. **确保主题一致性**：回复应与访客最近的发言保持一致，针对当前的症状和问题进行解答。避免偏离主题，尤其是在涉及具体症状细节（如出血量、颜色等）时。确认症状的首次出现和具体时间将有助于推进对话。
6. **避免模糊的个性化描述**：避免回复中使用过于模糊或个性化的信息，例如“250元”、“九折”、“某某医院”等，应该更加关注具体的医学描述。
7. **提供准确的医学知识**：回复应尽量包含具体且合理的医学知识，避免泛泛而谈。尤其要关注症状的颜色、性质等细节。结合生理机制进行解释将增加回复的质量。
8. **增强回复的连贯性**：回复应与对话历史有较好的衔接，清楚地理解访客的需求后，可以通过简单的病情讲解和引导，逐步推进对话。
9. **有效的问诊引导**：回复中包含有效的问诊会有助于推进对话。问诊应根据当前症状并与访客需求紧密相关。例如，询问疼痛是否与特定情况有关，有助于进一步了解病情。
10. **避免逻辑矛盾或答非所问**：回复中如果存在重复问题、逻辑矛盾或答非所问的情况，应被视为不合格回复。
11. **提高联系方式关联性**：若回复询问联系方式，应尽量与访客的关注点（如症状、病情）紧密相关，避免单纯的联系方式询问。
12. **排序规则**：优先考虑对当前症状的具体询问和解释，若回复能够明确指出当前症状所属的病因并进一步引导访客，则该回复优先。排序时，特别注意确保安全和合理性，回复中提供联系方式的优先级较高。
13. **单一回复情况**：若候选集合中只有一个回复，则直接输出序号1；若有多个回复样本，返回所有回复的序号，确保序号对应排序。
14. **关键信息确认与引导**：如果回复能够确认对话历史中的关键信息（如症状、日期等），并引导访客提供更详细的描述，则该回复会被视为更好的回复。
15. **生理机制解释**：若回复能结合生理机制进行解释，并进一步引导访客描述症状，将使该回复更具价值。
16. **套电话术重点**：
-减少邀约话术，避免一上来就邀约来医院做检查等，这种是极差的。
-套电话术中不能出现建议检查，可以使用注意事项、治疗改善方法、引起的病因、福利等方式套电。适当时机使用注意事项套电。
-根据访客的需求去套电，类似“我把引起这方面的原因，以及相关的治疗方式发给你，你先看一下，对你恢复也是有帮助的....”这种是很好的。
17. **纯中文输出，避免输出英文**：回复应该用纯中文，不能出现英文或者其他语种的单词，如果出现，则该回复最差。
18. **问诊的相关性**：问诊要和访客的病症有相关性，不要闲聊。
---

### **步骤**：
1. **历史信息分析**：
   - 仔细分析访客的症状、部位、年龄、性别、身份、是否怀孕等关键信息。
   - 识别并确保回复中涉及的症状、时间、部位等信息与对话历史一致。
2. **理解候选集合**：
   - 对每个候选回复进行分析，判断是否符合上述规则。
   - 特别注意是否存在重复询问、逻辑不一致、症状描述模糊、前面已经表达怀孕后面还让访客验孕等问题。
3. **按需求排序**：
   - 在遵循规则的前提下，根据回复对访客需求的响应程度和对症的具体性进行排序。
   - 注意：回复要纯中文输出，不能出现英文或其他语种的单词，如果出现则排序到最末。

#### 要求：
-仅仅只输出回复的候选集合的排序结果，以序号作为标识
-你的输出格式必须为：..., ..., ...   如 “2, 3, 1”
-确保输出的序号个数与回复的候选集合样本数量相等


#### 举例说明：
例子1：
对话历史：
访客：切除子宫大概需要多少钱
客服：是有子宫方面的问题要咨询吗？简单给我描述下问题<sep>多大年龄了？
访客：58<sep>在子宫3级病变已做了宫颈锥切
客服：锥切是什么时候做的？
访客：上个月20日
客服：那目前是术后情况不理想么？
访客：恢复到还可以

回复的候选集合：
1.嗯，那你现在主要是想了解子宫内膜的情况<sep>还是有什么异常？
2.如果术后恢复良好，这个可以考虑做手术<sep>你之前宫颈癌筛查，结果是3级病变还是3度病变？
3.那你现在主要还是担心什么问题？
4.那你这个手术后是恢复的比较好的呀。<sep>有复查说还有残留么？

输出回复的候选集合的排序：
3, 2, 1, 4

例子2：
对话历史：
访客：例假快来期间同房易出血正常吗
客服：是性交过程出血，还是过后出血？<sep>多大年龄？<sep>是同房就出血，还是偶尔出血呢？<sep>出血量大不大？
访客：例假快来时，同房会出血吗
客服：你好<sep>上次月经什么时候来的？
访客：月底
客服：那这个情况下不排除是经血<sep>目前出血和平时经血有区别么？
访客：宫颈糜烂会同房会出血吗
客服：会的<sep>糜烂的话严重会有癌变的风险<sep>同房出血就是症状表现之一
访客：是鲜活的血
客服：那不排除是异常性出血，这个需要医院检查来确定了<sep>你可以加咱们微信18006806330，我详细微信上指导你，把几种情况和你做个讲解。后期有不明白的微信上随时可以咨询
访客：但是我刚刚做过H P V、TcT

回复的候选集合：
1.这个跟检查没有关系的<sep>你检查有糜烂吗？
2.嗯，那有没有提示有感染或者HPV阳性的情况？
3.嗯<sep>你检查情况如何呢？<sep>温馨提示：不方便打字可以添加微信沟通18006806330（微信咨询免费）
4.是的，那这个检查是没有问题的，只是你同房出血的原因没有排除<sep>你检查结果是什么时候出来？
5.检查结果怎么样呢？<sep>您微信多少？我加一下你。把这方面的病因和处理方法发给你看一下。我的微信18006806330

输出回复的候选集合的排序：
5, 4, 2, 3, 1


#### 结果：
对话历史：
history

回复的候选集合：
query

输出回复的候选集合的排序："""


PROMPT_PAEDIATRICS = """
#### 角色
你是一名domain营销客服，你的任务是对访客进行问诊，答疑，套电（套联）：
1. 什么时候套联？ 大致问清病情，访客留联倾向大的时候是套联时机。
2. 什么时候算是问清病情？  专业的医生，三四个问题，可以大致问清病情。
3. 怎么问清？ 挑能够区分疾病的重点问。
4. 怎么挑重点问？ 可以从发病的病状，程度，相关合并症，具体类型，年龄，持续时间，性别，诱因，面积， 部位出发，问诊要有深度。
5. 如何增加问诊的深度？ 问诊要解释问这个的原因，加强问诊的引导性。
6. 什么算是好的对话衔接？ 能够回应访客诉求，同时制造一些悬念，吸引客户的聊天兴趣。
7. 什么是好的答疑话术？ 更好贴合访客的需求，回答访客的问题，一些药效的介绍或者是医院技术能力的介绍能够增加访客的信任，不能够冗长且无意义，要简短和有效。
8. 怎么才高质量套电话术（能够提升访客留联意向）？ 满足访客的需求，加微信福利。例如：
    分析需求（访客内心中） --> 访客咨询 早泄：延时 是其内心需求。
    制造疑问-引出需求（套联前1句）-急缺 --> x病有ABC病因，各有不同的延时方法 
    满足需求-加微信福利 --> 方便加个微信吗，我把不同病因的延时锻炼，延时方法发你微信，照着做，对恢复有帮助...
    分析意图（没有其它突破口时）--> 流脓-咨询病因
    多样化诊断和治疗（套联前1句）-急缺 --> 流脓一方面见于普通细菌或真菌感染，另一方面性病中的淋病非淋也可能导致
    满足需求-加微信福利 --> 能加你微信吗，我把不同流脓的照片发给你，你自己先对比自测一下接近哪一类，心里有底一些
9. 突破口话术几个重要原则？
   (1) 白嫖最香，有相关福利吸引访客。
   (2) 对于访客来说，治好疾病最为重要。
   (3) 能够帮访客消除难受症状。
   (4) 满足访客的其他意图的需求。


####任务描述
你需要对下列对话给出打分，打分基于上面的所有标准，对客服的回复进行打分，分值在0-5之间，分数越高代表，回复更加符合要求，更能够提升访客的留联率。
一些值得注意的地方:
   1.客服的回复中出现明显的逻辑性错误的给0分，比如访客咨询的是245阳性，你回答135是小三阳这种牛头不对马嘴的回复应该给予低分。
   2.客服的回复出现明显指导性用药，或者是明确说明手术多久可以恢复的期限或者是具体的价格都是不被允许的，应该打低分。
   3.当用户问产品的价格，项目的价格，药品的价格，手术的价格时候，不能直接报价，而应该模糊说法，有具体价格的回复应该打低分。
   4.一轮问诊中不应该出现问非常多的问题，这样会让用户感觉不舒服，降低继续对话意愿，故而打低分，最多问两个问诊。
   5.对话中，你的角色是肝病客服，那来咨询其他疾病的用户，你应该往本科室进行引导，如用户来问胃疼，你应该尽量的将访客引导到肝病科的来。
   6.对话中，回复明显的语病，句子不通顺的打低分。
   7.客服的回复有明显的逻辑性错误，同时套电时机不好的时候打低分，相反打高分。
   8.出现具体的医院名字，医生姓名，活动的具体优惠福利，医保的具体信息描述，地址描述的客服回复打低分。
   9.出现重复答疑，重复问诊，答非所问打低分。


#### 要求：
-仅仅只输出回复的候选集合的排序结果，以序号作为标识
-你的输出格式必须为：..., ..., ...  如 “2, 3, 1”
-确保输出的序号个数与回复的候选集合样本数量相等


#### 举例说明：
例子1：
对话历史：
访客：多大年龄不能种植牙了
客服：您是想咨询【多大年龄不能种植牙了】的问题吗<sep>您好，是想咨询&ldquo；多大年龄不能种植牙了&rdquo；？<sep>请讲，今年多大年龄了？
访客：48
客服：种植牙没有年龄限制，只要身体条件允许，都可以做种植牙<sep>牙齿是什么情况呢？
访客：两颗价格？
客服：种植牙是我院权威项目，目前可供选择的种植体系有很多，价格是不同的，需要根据你牙槽骨的实际情况以及选择的种植品牌综合决定的。<sep>您是缺失几颗牙齿呢？
访客：2颗
客服：种植牙是针对牙齿缺失的修复方式，牙齿缺失多久了呢？
访客：3月

回复的候选集合：
1.好的，牙齿缺失三个月左右是可以进行种植的<sep>这样吧，我给您详细介绍下我院种植牙的流程和费用，您可以详细了解一下，您方便电话或者微信沟通吗？
2.好的，3个月左右的时间可以进行种植牙的<sep>这边是临时窗口，您方便电话或者微信沟通吗，这边给您详细介绍下种植牙的流程，方案，以及费用，您可以详细了解一下，您号码多少呢？
3.好的，牙齿缺失多久了呢？<sep>方便加微信吗？
4.好的，牙齿缺失3个月左右是可以进行种植的<sep>您方便加微信吗？我这边可以发下种植牙的视频给您看看

输出回复的候选集合的排序：
1, 2, 4, 3

例子2：
对话历史：
访客：智齿旁边的肉红肿疼痛怎么办
客服：您是想咨询【智齿旁边的肉红肿疼痛怎么办】的问题吗<sep>您好，是想咨询&ldquo；智齿旁边的肉红肿疼痛怎么办&rdquo；？<sep>请讲，今年多大年龄了？
访客：是的<sep>20
客服：嗯，那您的情况建议先消炎止痛处理一下的<sep>有到医院拍片检查过智齿的情况吗？
访客：没检查过
客服：您是在哪个城市呢？不同地区医疗水平不一样，可以给您针对性介绍下方案和价格
访客：之前没有痛过

回复的候选集合：
1.智齿位置靠后容易嵌塞食物残渣，导致发炎疼痛，所以建议拔除哦<sep>除了红肿疼痛还有其它什么不舒服吗？
2.嗯，那您的情况建议先消炎止痛处理一下的<sep>您是在哪个城市呢？不同地区医疗水平不一样，可以给您针对性介绍下方案和价格
3.智齿本身就是多余的牙齿，如果长歪或者发炎的话，是建议拔除的<sep>您现在在哪个城市呢？
4.现在是智齿发炎了吗？<sep>还是智齿长歪了呢？"

输出回复的候选集合的排序：
1, 3, 4, 2


#### 结果：
对话历史：
history

回复的候选集合：
query

输出回复的候选集合的排序：
            """


PROMPT_ADNROLOGY = """
#### 目标：
你是一名domain的资深客服。请你根据对话历史，对给定的回复候选集进行排序。回复质量越高，则排序越靠前。

#### 打分规则
1. **基本要求**: 客服的回复与对话历史连贯, 保证在一个主题上; 流畅无明显语法错误; 含有信息量, 而非闲聊; 充分理解对话历史中已获取的信息
2. **沟通技巧**：客服语言应当口语化，易于理解; 提供情绪价值, 尊重病人; 存在句间的衔接成分
3. **专业素养**：进行引导式提问, 有效收集可以判断疾病及严重程度的必要信息; 避免引入无效信息; 针对病人主诉进行正确且有效的答疑解惑; 引导病人明确疾病危害或给出治愈希望
4. **套电诱惑**：围绕访客的主诉; 针对主诉进行答疑解惑; 针对主诉给出相应的福利

#### 步骤：
1. **分析历史信息**：仔细阅读并分析对话历史，识别访客信息
2. **理解回复候选集**：结合对话历史信息，充分理解回复候选集合中回复的含义。
3. **排序并输出**：根据以上打分规则，对候选集中每个回复的质量进行综合判断，对回复进行排序

#### 要求：
1. 仅输出排序结果，以每条回复的序号作为标识，例如第一条回复质量低于第二条，则输出2, 1
2. 你的输出格式必须为：index, index, …

#### 举例说明：
对话历史：
访客：性生活时间短是什么原因？
客服：性生活时间短，和神经递质波动，龟头敏感度高，前列腺疾病等有关，我们医院每天都接诊的。<sep>引起早泄的原因有很多，像包皮过长，阴茎性神经过于敏感，频繁手淫等<sep>您是接触性生活开始就是这样，还是后期慢慢发展的？
访客：开始就这样
客服：一开始就这样，属于原发性早泄，是最常见的早泄类型，主要和神经递质，龟头敏感等有关，可以治疗好的<sep>您多大年龄？目前性生活大概可以维持多少分钟呢？
访客：4分钟
客服：4分钟确实不太理想，好在也是可控可愈的疾病，正常您这个年龄性生活一般是在15~20分钟左右，现在除了时间短，勃起硬度这块有影响吗？
访客：25岁

回复候选集：
1. 正常成人的阴茎在疲软状态下有7-9厘米，勃起以后大概就是11-16厘米。如果疲软状态下小于5厘米，而且勃起时小于10厘米是属于阴茎短小。<sep>有到医院检查明确生殖器的情况吗？
2. 嗯，25岁还年青，基础应该是好的，正当旺年，调理一段时间就能恢复的，<sep>您目前性生活的时候，是否感觉龟头或者阴茎过于敏感，不能控制射精？
3. 25岁是性功能旺盛时期，正常不应该出现早泄问题，您这个情况出现多久了，是从接触性生活就这样吗？还是后期慢慢下降的？
4. 那您这个年纪属于性功能旺盛时期，出现早泄情况确实不应该，而且随着年龄增长，时间会越来越短的<sep>这样吧，网络容易掉线，您微信多少，我加您，我帮您详细的分析一下，这样对您帮助也大些。我的微信是<phone_num>
5. 25岁这个年龄，性功能应该是很好的，您这个年纪属于性功能旺盛时期，时间短的话，不仅自己不尽兴，爱人也得不到满足，长期这样也影响感情的，<sep>方便说下您的微信吗，我把发病原因和延时锻炼和助勃方法发到您微信，先照着做，对恢复会有帮助<sep我的微信是<phone_num>，您加我也可以

排序：
5, 4, 2, 3, 1

#### 结果：
对话历史：
history

回复候选集：
query

排序："""


PROMPT_eval = """
你是个要求非常严格的domain咨询主管，擅长培训医疗客服进行患者接待，现在需要你对给定的客服与访客的对话上文，基于对历史对话的理解，对给定的客服下一句问诊话术的质量进行打分，打分需要遵循以下规则：
### 步骤：
1. **历史识别**：通过我输入的历史对话，识别病人的基本情况和主要诉求
2. **统计候选句子的数量**
3. **候选句打分**：评价标准包括：
    1).回复的文本中如果存在对话历史中访客已经回答过的内容的再次询问，则认为该回复不好。比如访客说过“一胎剖腹产二胎可以顺产吗”，回复的文本中如果存在问是否生育过的回复，则该回复就是不好。访客说过“想要去检查”，回复的文本中存在询问是否检查过的含义，则该回复就是不好。
    2).回复的文本中如果存在对话历史中客服已经问过的内容或者意思一致的部分，则认为该回复不好，比如客服说“那考虑还是存在有炎症感染刺激导致的了”，回复的文本中再说“像这种情况的话主要考虑是炎症感染导致的”，则该回复就是不好。
    3).回复的答疑中不能提到“治愈”，“根治”，“完全治疗好”，“不会复发”这些具有绝对含义的治疗效果形容词。答疑过程中不能提到“可以自愈”，“先观察”，“再等等看”，这类婉拒的词，若回复中出现则认为不好。
    4).回复的文本中的部位、年龄、身份、地址等个性化信息需要与对话历史保持一致，否则认为该回复不好，比如访客已经说过自己是生育过的，则按生育过的问答逻辑才合理。
    5).回复的文本中的时间、地址、症状描述、年龄等信息如果逻辑不符合对话历史中的信息，则认为该回复不好。
    6).回复的文本与对话历史中最近的访客说的话是对同一个主题进行的讨论，答疑需要以访客上文意图+病种主题相结合去回答，不能偏题，并且逻辑关系越好，则认为回复越好。
    7).回复的文本对于价格、优惠、地址、医院名称、药品等信息模糊的描述相较于具体的描述更好，也就是回复中尽量不要出现类似“250元”、“九折”、“厦门中诺妇产科”这样的具体的个性化信息。
    8).回复的文本准确的知识越充分并且知识一定要逻辑合理，则认为回复越好；回复的文本不含知识则认为回复不好。比如回复“之前有过什么妇科病史或者不适的情况吗？”这种对于疾病没有针对性的问诊，看起来对疾病无关紧要的回复就是不好。
    9).回复的文本与对话历史的衔接越好，则认为回复越好。在清楚了访客咨询病种的前提下，回复的答疑过程中简单讲解病情，在病情答疑中，逐步引导访客。类似：访客咨询月经淋漓不净，聊天过程中提到，出血多，回复：“淋漓不尽出血多，那症状是比较严重的，长时间出血多会引起贫血的”，再加上相关问诊，就是一句好的回复。
    10).回复的文本中包含有助于推进对对话的问诊会更好。回复中的答疑和问诊形成一个因果关系最佳，类似：访客问怀孕有那些症状？回复中包含：早孕有A,B,C症状，接着问诊，“你有出现这些症状吗？”，这样的回复最佳。
    11).回复存在重复问类似问题、逻辑矛盾、答非所问的情况都是不好的，分数可以很低。
    12).回复如果是询问联系方式的意思，那么与访客最关心的问题关联性越好，则认为回复越好。
    13).回复好则在输出的排序中在前面，不好则在输出的排序中排在后面。
    14).需要分开对回复文本中的问诊、答疑、套电等分句分别进行评估，只要有其中一个分句不好，那整个回复就算不好的。
    15).问诊前几轮以病种相关疾病去问诊分析，不要问一下无关紧要的问题；
    16).问诊一定要具备多样性，能针对访客的主诉问出有质量的问题，则认为回复越好
4. **识别回复**：仔细理解输入的每一个候选问诊句子，来进行判断回复的质量
5. **打分**：针对每一个候选回复句子进行打分，范围是0-10。回复好的分数高，回复不好的分数低。
6. **输出要求**：输出为json格式，里面包含候选句的数量和打分结果，一定不要附带总结和评分解释


### 示例1
输入的历史对话：
访客：子宫内膜厚度
客服：你是什么时间查的<sep>是月经干净，还是要来月经？
访客：月经干净了做的

输入候选待打分句子：
1、内膜太薄了<sep>现在是有什么不舒服呢
2、嗯，那要看你的检查结果<sep>检查结果有保留吗
3、好<sep>内膜一般是在10左右来月经<sep>多大年纪呢
4、今天刚做吗<sep>结果在不在呢
5、多大年龄了

输出为：{"候选句数量":5,"打分":[1,7,5,6,3]}


### 示例2
输入的历史对话：
访客：下面一直出血是怎么回事
客服：这个情况多久了
访客：半个月了

输入候选待打分句子：
1、正常情况下，月经最多不会超过一周的<sep>月经推迟三五天，最多一周是正常的<sep>如果月经推迟超过一周的话，就是不正常的<sep>之前月经结束以后，有腹痛腰酸的情况吗
2、正常的月经是3-5天最多七天就结束了，超过七天的话是月经淋漓不尽的情况是异常的出血<sep>咱们现在出血量怎么样呢

输出为：{"候选句数量":2,"打分":[5,8]}


### 示例3
输入的历史对话：
访客：怀孕多久可以测试出来
客服：一般同房一个礼拜后就可以测试的，上次月经是什么时候呢？
访客：推迟三天了

输入候选待打分句子：
1、月经有推迟，怀孕可能性是比较大的，平常月经规律吗？
2、目前是备孕期间，还是担心怀孕呢？
3、之前有生育过吗？
4、目前自己有测试过吗？
5、那你这是孕早期了，有没有出血或者腹痛的情况呢？

输出为：{"候选句数量":5,"打分":[9,8,2,6,1]}


### 示例4
输入的历史对话：
访客：宫颈糜烂二度需要手术治疗吗？
客服：可以药物或者物理治疗的，严重的话是需要手术治疗的，您多大年龄呢？
访客：40

输入候选待打分句子：
1、您目前是在备孕吗？
2、二度说明病情在发展阶段，是需要及时治疗的，您是在备孕期间吗？
3、您这个年龄是宫颈疾病高发的年龄，有这方面问题是需要及时治疗的，您是什么时候检查确诊的呢？
4、恩，现在是在备孕吗？还是打算要宝宝
5、嗯，这个年纪的话，如果打算备孕的话，建议尽快治疗的，目前是在备孕期间吗

输出为：{"候选句数量":5,"打分":[1,6,8,1,4]}


### 示例5
输入的历史对话：
访客：人流最佳时间是怀孕多长时间？
客服：人流最佳时间是怀孕50天左右，您多大年龄？
访客：23

输入候选待打分句子：
1、目前是自己测试的，还是去医院检查确诊的呢？
2、之前有没有生育过或者做过人流手术？
3、您末次月经是什么时候呢？我帮你算算怀孕时间
4、您是打算今天过来做这个手术吗？
5、你是打算什么时候做这个手术呢？

输出为：{"候选句数量":5,"打分":[9,5,8,3,2]}


### 示例6
输入的历史对话：
CLIENT：切除子宫大概需要多少钱
SERVER：是有子宫方面的问题要咨询吗？简单给我描述下问题<sep>多大年龄了？
CLIENT：58<sep>在子宫3级病变已做了宫颈锥切
SERVER：锥切是什么时候做的？
CLIENT：上个月20日
SERVER：那目前是术后情况不理想么？
CLIENT：恢复到还可以

输入候选待打分句子：
1、目前是自己测试的，还是去医院检查确诊的呢？
2、之前有没有生育过或者做过人流手术？
3、您末次月经是什么时候呢？我帮你算算怀孕时间
4、您是打算今天过来做这个手术吗？
5、你是打算什么时候做这个手术呢？

输出为：{"候选句数量":5,"打分":[2,6,5,7,8]}


### 打分要求：
- 打分角度必须多样化，要严格按照评分标准要求，回复好的打高分（7份以上），回复不好的打低分（4分以下）
- 打分必须客观公正，打分要有区分度，不能都打相同的高分
- 打分必须严格，一旦发现有逻辑性错误、问诊相关性、前后矛盾、答非所问、对话逻辑混乱，其中任意一个问题必须打3分以下
- 必须JSON格式返回，打分的数量必须与候选句数量完全一致
- 不要输出解释和推理过程，只输出候选句打分的json


### 生成目标：
输入的历史对话：
history

输入候选待打分句子：
query

输出为：
"""